@@ -7,7 +7,7 @@ pub type Result<T> = std::result::Result<T, Error>;
 
 #[derive(Clone, Debug, PartialEq)]
 pub enum Error {
-    Message(String),
+    Message(Box<str>),
     Eof,
     InvalidBoolEncoding,
     InvalidChar,
@@ -18,13 +18,13 @@ pub enum Error {
 
 impl ser::Error for Error {
     fn custom<T: Display>(msg: T) -> Self {
-        Error::Message(msg.to_string())
+        Error::Message(msg.to_string().into_boxed_str())
     }
 }
 
 impl de::Error for Error {
     fn custom<T: Display>(msg: T) -> Self {
-        Error::Message(msg.to_string())
+        Error::Message(msg.to_string().into_boxed_str())
     }
 }
 
